@@ -9,3 +9,5 @@ STR_LEN_MIN = 0
 STR_LEN_MAX = 32
 LIST_LEN_MIN = 0
 LIST_LEN_MAX = 16
+BYTES_LEN_MIN = 0
+BYTES_LEN_MAX = 32
